EXPORTS
	?Cid@CDrmFileContent@ReferenceTestAgent@@QAEABVTDesC8@@XZ @ 1 NONAME ; class TDesC8 const & ReferenceTestAgent::CDrmFileContent::Cid(void)
	?Cid@CRightsObject@ReferenceTestAgent@@QAEABVTDesC8@@XZ @ 2 NONAME ; class TDesC8 const & ReferenceTestAgent::CRightsObject::Cid(void)
	?CloseContainer@CDrmFiles@ReferenceTestAgent@@QAEHXZ @ 3 NONAME ; int ReferenceTestAgent::CDrmFiles::CloseContainer(void)
	?CurrentContainer@CDrmFiles@ReferenceTestAgent@@QAEAAVCDrmFileContainer@2@XZ @ 4 NONAME ; class ReferenceTestAgent::CDrmFileContainer & ReferenceTestAgent::CDrmFiles::CurrentContainer(void)
	?DrmFilesL@CDrmFilesParser@ReferenceTestAgent@@QAEAAVCDrmFiles@2@XZ @ 5 NONAME ; class ReferenceTestAgent::CDrmFiles & ReferenceTestAgent::CDrmFilesParser::DrmFilesL(void)
	?DrmRightsL@CDrmRightsParser@ReferenceTestAgent@@QAEAAVCDrmRights@2@XZ @ 6 NONAME ; class ReferenceTestAgent::CDrmRights & ReferenceTestAgent::CDrmRightsParser::DrmRightsL(void)
	?EvaluateIntent@CRightsObject@ReferenceTestAgent@@QAEHW4TIntent@ContentAccess@@@Z @ 7 NONAME ; int ReferenceTestAgent::CRightsObject::EvaluateIntent(enum ContentAccess::TIntent)
	?ExecuteIntentL@CRightsObject@ReferenceTestAgent@@QAEXW4TIntent@ContentAccess@@@Z @ 8 NONAME ; void ReferenceTestAgent::CRightsObject::ExecuteIntentL(enum ContentAccess::TIntent)
	?ExternalizeL@CRightsObject@ReferenceTestAgent@@QAEXAAVRWriteStream@@@Z @ 9 NONAME ; void ReferenceTestAgent::CRightsObject::ExternalizeL(class RWriteStream &)
	?FindL@CDrmFiles@ReferenceTestAgent@@QAEAAVCDrmFileContent@2@ABVTDesC16@@@Z @ 10 NONAME ; class ReferenceTestAgent::CDrmFileContent & ReferenceTestAgent::CDrmFiles::FindL(class TDesC16 const &)
	?GetAttribute@CDrmFileContent@ReferenceTestAgent@@QAEHHAAH@Z @ 11 NONAME ; int ReferenceTestAgent::CDrmFileContent::GetAttribute(int, int &)
	?GetAttributeSet@CDrmFileContent@ReferenceTestAgent@@QAEHAAVRAttributeSet@ContentAccess@@@Z @ 12 NONAME ; int ReferenceTestAgent::CDrmFileContent::GetAttributeSet(class ContentAccess::RAttributeSet &)
	?GetEmbeddedObjectsL@CDrmFileContainer@ReferenceTestAgent@@QAEXAAV?$RStreamablePtrArray@VCEmbeddedObject@ContentAccess@@@ContentAccess@@@Z @ 13 NONAME ; void ReferenceTestAgent::CDrmFileContainer::GetEmbeddedObjectsL(class ContentAccess::RStreamablePtrArray<class ContentAccess::CEmbeddedObject> &)
	?GetEmbeddedObjectsL@CDrmFileContainer@ReferenceTestAgent@@QAEXAAV?$RStreamablePtrArray@VCEmbeddedObject@ContentAccess@@@ContentAccess@@W4TEmbeddedType@4@@Z @ 14 NONAME ; void ReferenceTestAgent::CDrmFileContainer::GetEmbeddedObjectsL(class ContentAccess::RStreamablePtrArray<class ContentAccess::CEmbeddedObject> &, enum ContentAccess::TEmbeddedType)
	?GetStringAttribute@CDrmFileContent@ReferenceTestAgent@@QAEHHAAVTDes16@@@Z @ 15 NONAME ; int ReferenceTestAgent::CDrmFileContent::GetStringAttribute(int, class TDes16 &)
	?GetStringAttributeSet@CDrmFileContent@ReferenceTestAgent@@QAEHAAVRStringAttributeSet@ContentAccess@@@Z @ 16 NONAME ; int ReferenceTestAgent::CDrmFileContent::GetStringAttributeSet(class ContentAccess::RStringAttributeSet &)
	?MergeL@CRightsObject@ReferenceTestAgent@@QAEXAAV12@@Z @ 17 NONAME ; void ReferenceTestAgent::CRightsObject::MergeL(class ReferenceTestAgent::CRightsObject &)
	?NewL@CDrmFilesParser@ReferenceTestAgent@@SAPAV12@AAVCVirtualFile@2@@Z @ 18 NONAME ; class ReferenceTestAgent::CDrmFilesParser * ReferenceTestAgent::CDrmFilesParser::NewL(class ReferenceTestAgent::CVirtualFile &)
	?NewL@CDrmRightsParser@ReferenceTestAgent@@SAPAV12@AAVCVirtualFile@2@@Z @ 19 NONAME ; class ReferenceTestAgent::CDrmRightsParser * ReferenceTestAgent::CDrmRightsParser::NewL(class ReferenceTestAgent::CVirtualFile &)
	?NewL@CDrmRightsParser@ReferenceTestAgent@@SAPAV12@XZ @ 20 NONAME ; class ReferenceTestAgent::CDrmRightsParser * ReferenceTestAgent::CDrmRightsParser::NewL(void)
	?NewL@CRightsObject@ReferenceTestAgent@@SAPAV12@AAVRReadStream@@H@Z @ 21 NONAME ; class ReferenceTestAgent::CRightsObject * ReferenceTestAgent::CRightsObject::NewL(class RReadStream &, int)
	?OpenContainer@CDrmFiles@ReferenceTestAgent@@QAEHABVTDesC16@@@Z @ 22 NONAME ; int ReferenceTestAgent::CDrmFiles::OpenContainer(class TDesC16 const &)
	?ParseL@CDrmRightsParser@ReferenceTestAgent@@QAEXABVTDesC8@@@Z @ 23 NONAME ; void ReferenceTestAgent::CDrmRightsParser::ParseL(class TDesC8 const &)
	?Read@CDrmFileContent@ReferenceTestAgent@@QAEHAAVTDes8@@H@Z @ 24 NONAME ; int ReferenceTestAgent::CDrmFileContent::Read(class TDes8 &, int)
	?SearchL@CDrmFileContainer@ReferenceTestAgent@@QAEHAAV?$RStreamablePtrArray@VCEmbeddedObject@ContentAccess@@@ContentAccess@@ABVTDesC8@@H@Z @ 25 NONAME ; int ReferenceTestAgent::CDrmFileContainer::SearchL(class ContentAccess::RStreamablePtrArray<class ContentAccess::CEmbeddedObject> &, class TDesC8 const &, int)
	?Seek@CDrmFileContent@ReferenceTestAgent@@QAEHW4TSeek@@AAH@Z @ 26 NONAME ; int ReferenceTestAgent::CDrmFileContent::Seek(enum TSeek, int &)
	?Size@CDrmFileContent@ReferenceTestAgent@@QAEHAAH@Z @ 27 NONAME ; int ReferenceTestAgent::CDrmFileContent::Size(int &)
	?WriteDescription@CRightsObject@ReferenceTestAgent@@QAEXAAVRFile@@@Z @ 28 NONAME ; void ReferenceTestAgent::CRightsObject::WriteDescription(class RFile &)
	?Content@CDrmFiles@ReferenceTestAgent@@QAEAAVCDrmFileContent@2@H@Z @ 29 NONAME ; class ReferenceTestAgent::CDrmFileContent & ReferenceTestAgent::CDrmFiles::Content(int)
	?ContentCount@CDrmFiles@ReferenceTestAgent@@QAEHXZ @ 30 NONAME ; int ReferenceTestAgent::CDrmFiles::ContentCount(void)
	?FindL@CDrmFiles@ReferenceTestAgent@@QAEAAVCDrmFileContent@2@ABVTDesC8@@@Z @ 31 NONAME ; class ReferenceTestAgent::CDrmFileContent & ReferenceTestAgent::CDrmFiles::FindL(class TDesC8 const &)
	?Remove@CDrmRights@ReferenceTestAgent@@QAEXH@Z @ 32 NONAME ; void ReferenceTestAgent::CDrmRights::Remove(int)
	?Rights@CDrmRights@ReferenceTestAgent@@QAEAAVCRightsObject@2@H@Z @ 33 NONAME ; class ReferenceTestAgent::CRightsObject & ReferenceTestAgent::CDrmRights::Rights(int)
	?RightsCount@CDrmRights@ReferenceTestAgent@@QAEHXZ @ 34 NONAME ; int ReferenceTestAgent::CDrmRights::RightsCount(void)
	?SetCommonSourceFileL@CDrmFileContent@ReferenceTestAgent@@QAEXAAVRFile@@AAVRSemaphore@@HH@Z @ 35 NONAME ; void ReferenceTestAgent::CDrmFileContent::SetCommonSourceFileL(class RFile &, class RSemaphore &, int, int)
	?MimeType@CDrmFileContent@ReferenceTestAgent@@QAEABVTDesC8@@XZ @ 36 NONAME ; class TDesC8 const & ReferenceTestAgent::CDrmFileContent::MimeType(void)
	?SetEntireFileL@CDrmFiles@ReferenceTestAgent@@QAEXAAVRFile@@AAVRSemaphore@@HH@Z @ 37 NONAME ; void ReferenceTestAgent::CDrmFiles::SetEntireFileL(class RFile &, class RSemaphore &, int, int)
	?SetDeleteKeyL@CRightsObject@ReferenceTestAgent@@QAEXABVTDesC8@@@Z @ 38 NONAME ; void ReferenceTestAgent::CRightsObject::SetDeleteKeyL(class TDesC8 const &)
	?DeleteKey@CRightsObject@ReferenceTestAgent@@QAEABVTDesC8@@XZ @ 39 NONAME ; class TDesC8 const & ReferenceTestAgent::CRightsObject::DeleteKey(void)
	?Read@CDrmFileContent@ReferenceTestAgent@@QAEHHAAVTDes8@@H@Z @ 40 NONAME ; int ReferenceTestAgent::CDrmFileContent::Read(int, class TDes8 &, int)

